"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dbProvider = exports.getDatabaseProviders = void 0;
const mysql_base_1 = require("../mysql.base");
const config_1 = require("@nestjs/config");
async function getDatabaseProviders(host, port, username, password, database, any) {
    const base = {
        type: "mysql",
        host,
        port: parseInt(port, 10),
        username,
        password,
        database,
        synchronize: false,
        logging: false,
        extra: {
            connectionLimit: 5000,
        },
        charset: "utf8mb4",
        entities: ["src/**/*.entity.ts", "dist/**/*.entity.js"],
        subscribers: ["src/**/*.subscribe.ts"],
        namingStrategy: new mysql_base_1.ConstraintSnakeNamingStrategy(),
    };
    if (any) {
        return Object.assign(base, Object.assign({}, any));
    }
    return base;
}
exports.getDatabaseProviders = getDatabaseProviders;
exports.dbProvider = {
    import: [config_1.ConfigModule],
    inject: [config_1.ConfigService],
    useFactory: async (configService) => await getDatabaseProviders(configService.get("MYSQL_HOST"), configService.get("MYSQL_PORT"), configService.get("MYSQL_USERNAME"), configService.get("MYSQL_PASSWORD"), configService.get("MYSQL_DATABASE")),
};
//# sourceMappingURL=database.provider.js.map